==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Az eszköz foglalt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Használta:</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Utolsó videó levélként</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Egy vagy több kiválasztott videó levélként</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>A videó csatolva</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Válasszon ki egy vagy több fájlt</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Kerettel</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Az eszköz foglalt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Használta:</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Hangrendszer</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Egérmutató elrejtése</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videó mentés helye</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lejátszó</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimalizálása a felvétel megkezdésekor</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Felvétel ideje</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Méret KB-ban</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Felvétel képernyőmérete</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Fps beállítás</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Könyvtár megnyitása</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Visszaszámlálás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Utolsó videó lejátszása</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Videó küldése</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Képkockák száma másodpercenként</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Indít</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Weboldal</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Levelezőlista</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Támogatás</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Fejlesztés</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Képkocka</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Képrögzítő program</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Fordítás</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Forráskód</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Megjelenítés a tálcán</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Új verzió érhető el</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Válasszon webkamerát</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Tükrözött</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Képernyő</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Összes képernyő</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Az eszköz foglalt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Használta:</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Utolsó videó levélként</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Egy vagy több kiválasztott videó levélként</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Telepítsen egy videólejátszót</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>A videó csatolva</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Válasszon ki egy vagy több fájlt</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Kerettel</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Jobb klikk a menühöz</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Felhasználó által definiált</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Az eszköz foglalt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Használta:</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation>dupla kattintással kiterjesztve a széléig</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Hangrendszer</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Egérmutató elrejtése</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videó mentés helye</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lejátszó</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimalizálása a felvétel megkezdésekor</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Felvétel ideje</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Méret KB-ban</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Felvétel képernyőmérete</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Fps beállítás</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Könyvtár megnyitása</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Visszaszámlálás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Utolsó videó lejátszása</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Videó küldése</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Képkockák száma másodpercenként</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Indít</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Weboldal</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Támogatás</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Fejlesztés</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Képkocka</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Képrögzítő program</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Fordítás</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Forráskód</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Megjelenítés a tálcán</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Új verzió érhető el</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Válasszon webkamerát</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Tükrözött</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Képernyő</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Összes képernyő</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Fejlesztői honlap</translation>
    </message>
</context>
</TS>
